mailr4146 - /1.3/test_suite/unit_tests/_prompt/test_value.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on December 09, 2007 - 17:41:
Author: bugman
Date: Sun Dec  9 17:41:47 2007
New Revision: 4146

URL: http://svn.gna.org/viewcvs/relax?rev=4146&view=rev
Log:
Added the infrastructure for the user function arg unit tests of prompt.value.


Added:
    1.3/test_suite/unit_tests/_prompt/test_value.py
      - copied, changed from r4144, 
1.3/test_suite/unit_tests/_prompt/test_molecule.py

Copied: 1.3/test_suite/unit_tests/_prompt/test_value.py (from r4144, 
1.3/test_suite/unit_tests/_prompt/test_molecule.py)
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/_prompt/test_value.py?p2=1.3/test_suite/unit_tests/_prompt/test_value.py&p1=1.3/test_suite/unit_tests/_prompt/test_molecule.py&r1=4144&r2=4146&rev=4146&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/_prompt/test_molecule.py (original)
+++ 1.3/test_suite/unit_tests/_prompt/test_value.py Sun Dec  9 17:41:47 2007
@@ -25,139 +25,17 @@
 
 # relax module imports.
 from data import Data as relax_data_store
-from generic_fns import residue
-from prompt.molecule import Molecule
-from relax_errors import RelaxNoneStrError, RelaxStrError
-from test_suite.unit_tests.molecule_testing_base import Molecule_base_class
+from prompt.value import Value
+from relax_errors import RelaxError
+from test_suite.unit_tests.value_testing_base import Value_base_class
 
 # Unit test imports.
 from data_types import DATA_TYPES
 import fake_relax
 
 
-class Test_molecule(Molecule_base_class, TestCase):
-    """Unit tests for the functions of the 'prompt.molecule' module."""
+class Test_value(Value_base_class, TestCase):
+    """Unit tests for the functions of the 'prompt.value' module."""
 
     # Instantiate the user function class.
-    molecule_fns = Molecule(fake_relax.fake_instance())
-    residue_fns = residue
-
-
-    def test_copy_argfail_pipe_from(self):
-        """Test the proper failure of the molecule.copy() user function for 
the pipe_from argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the None and str arguments, and skip them.
-            if data[0] == 'None' or data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxNoneStrError, self.molecule_fns.copy, 
pipe_from=data[1], mol_from='#Old mol', mol_to='#Old mol')
-
-
-    def test_copy_argfail_mol_from(self):
-        """Test the proper failure of the molecule.copy() user function for 
the mol_from argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the str argument, and skip it.
-            if data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxStrError, self.molecule_fns.copy, 
mol_from=data[1], mol_to='#Old mol')
-
-
-    def test_copy_argfail_pipe_to(self):
-        """Test the proper failure of the molecule.copy() user function for 
the pipe_to argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the None and str arguments, and skip them.
-            if data[0] == 'None' or data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxNoneStrError, self.molecule_fns.copy, 
pipe_to=data[1], mol_from='#Old mol', mol_to='#New mol2')
-
-
-    def test_copy_argfail_mol_to(self):
-        """Test the proper failure of the molecule.copy() user function for 
the mol_to argument."""
-
-        # Set up some data.
-        self.setup_data()
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the None and str arguments, and skip them.
-            if data[0] == 'None' or data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxNoneStrError, self.molecule_fns.copy, 
mol_from='#Old mol', mol_to=data[1])
-
-
-    def test_create_argfail_mol_name(self):
-        """Test the proper failure of the molecule.create() user function 
for the mol_name argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the str arguments, and skip them.
-            if data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxStrError, self.molecule_fns.create, 
mol_name=data[1])
-
-
-    def test_delete_argfail_mol_id(self):
-        """Test the proper failure of the molecule.delete() user function 
for the mol_id argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the str arguments, and skip them.
-            if data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxStrError, self.molecule_fns.delete, 
mol_id=data[1])
-
-
-    def test_display_argfail_mol_id(self):
-        """Test the proper failure of the molecule.display() user function 
for the mol_id argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the None and str arguments, and skip them.
-            if data[0] == 'None' or data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxNoneStrError, self.molecule_fns.display, 
mol_id=data[1])
-
-
-    def test_rename_argfail_mol_id(self):
-        """Test the proper failure of the molecule.rename() user function 
for the mol_id argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the str arguments, and skip them.
-            if data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxStrError, self.molecule_fns.rename, 
mol_id=data[1])
-
-
-    def test_rename_argfail_new_name(self):
-        """Test the proper failure of the molecule.rename() user function 
for the new_name argument."""
-
-        # Loop over the data types.
-        for data in DATA_TYPES:
-            # Catch the str arguments, and skip them.
-            if data[0] == 'str':
-                continue
-
-            # The argument test.
-            self.assertRaises(RelaxStrError, self.molecule_fns.rename, 
new_name=data[1])
+    value_fns = Value(fake_relax.fake_instance())




Related Messages


Powered by MHonArc, Updated Sun Dec 09 18:20:10 2007